<?php
//turn error reporting on
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors',TRUE);
ini_set('error_log','errors.txt');

define('ERROR_LOG_FILE', 'errors.txt');
define('FW_UPDATE_VERSION', '0.138');
define('BOOTLOADER_VERSION', '1.4');

/**
* Custom error handler
* @param integer $code
* @param string $description
* @param string $file
* @param interger $line
* @param mixed $context
* @return boolean
*/
function handleError($code, $description, $file = null, $line = null, $context = null) {
    $displayErrors = ini_get("display_errors");
    $displayErrors = strtolower($displayErrors);
    if (error_reporting() === 0 || $displayErrors === "on") {
        return false;
    }
    list($error, $log) = mapErrorCode($code);
    $data = array(
        'level' => $log,
        'code' => $code,
        'error' => $error,
        'description' => $description,
        'file' => $file,
        'line' => $line,
        'context' => $context,
        'path' => $file,
        'message' => $error . ' (' . $code . '): ' . $description . ' in [' . $file . ', line ' . $line . ']'
    );
    return fileLog($data);
}

/**
* This method is used to write data in file
* @param mixed $logData
* @param string $fileName
* @return boolean
*/
function fileLog($logData, $fileName = ERROR_LOG_FILE) {
    $fh = fopen($fileName, 'a+');
    if (is_array($logData)) {
        $logData = print_r($logData, 1);
    }
    $status = fwrite($fh, $logData);
    fclose($fh);
    return ($status) ? true : false;
}

/**
* Map an error code into an Error word, and log location.
*
* @param int $code Error code to map
* @return array Array of error word, and log location.
*/
function mapErrorCode($code) {
    $error = $log = null;
    switch ($code) {
        case E_PARSE:
        case E_ERROR:
        case E_CORE_ERROR:
        case E_COMPILE_ERROR:
        case E_USER_ERROR:
            $error = 'Fatal Error';
            $log = LOG_ERR;
            break;
        case E_WARNING:
        case E_USER_WARNING:
        case E_COMPILE_WARNING:
        case E_RECOVERABLE_ERROR:
            $error = 'Warning';
            $log = LOG_WARNING;
            break;
        case E_NOTICE:
        case E_USER_NOTICE:
            $error = 'Notice';
            $log = LOG_NOTICE;
            break;
        case E_STRICT:
            $error = 'Strict';
            $log = LOG_NOTICE;
            break;
        case E_DEPRECATED:
        case E_USER_DEPRECATED:
            $error = 'Deprecated';
            $log = LOG_NOTICE;
            break;
        default :
            break;
    }
    return array($error, $log);
}

//calling custom error handler
set_error_handler("handleError");


if( (error_reporting()) == 0 ) 
{
	trigger_error('PHP PARSE ERROR',E_ALL);
	return;
}

//Parses HTTP headers
 
$headers = apache_request_headers();  
//print_r(http_parse_headers($headers));

//get the JSON file
$jsonData = file_get_contents("php://input");
$clen=strlen($jsonData);

//var_dump($jsonData);
//$jsonData = file_get_contents("gesysense.json");

$phpArray = json_decode($jsonData);
//printf("<h3>%s</h3>", "The Decoded JSON is: \n"); 

//print_r($phpArray);

//connect to the database
$con = mysqli_connect("localhost","root","","ttr4daten");
if (mysqli_connect_errno()) {
	echo 'Failed to connect to MySQL: ' . mysqli_connect_error();
	exit();
};
//echo 'Erfolgreich verbunden\n';
//printf("<h3>%s</h3>", "\n \n");
//$row=$phpArray;
if(array_key_exists("receiver",$phpArray)){
	$receiver= $phpArray->receiver;
	//loop through the JSON array data
	echo '{';
	flush();
/**/
	ob_end_flush();
	ob_start();
//	sleep(1);
	
	echo '
		';
	flush();
	ob_end_flush();
	ob_start();
//	sleep(1);

	echo '
		';
	flush();
	ob_end_flush();
	ob_start();
//	sleep(1);
/**/
	foreach ($phpArray->data as $row) {
	$sn=$row->sn;
	$value=$row->value;
	$type=$row->type;
	$rssi=$row->rssi;
	$quality=$row->quality;
	$battery=$row->battery;
	$timestamp=$row->timestamp;
	$receiveTime=date("Y-m-d H:i:s"); 
	
	//var_dump($receiveTime);

	$sqlSelect = "Select SN from ttr4postdaten where SN = '$sn' and Receiver = '$receiver'";
	//var_dump($sqlSelect); 
	
	//run the query
	$resultselect = mysqli_query($con, $sqlSelect);
	
		
		//check the outcome
		if ($resultselect->num_rows == 0): //INSERT into MySQL if its new Record
		{
				
			//prepare the SQL Statement	

			$sqlStr = "INSERT INTO ttr4postdaten (Receiver, SN, Value, Type, RSSI, Quality, Battery, Timestamp ,receiveTime ) 
			VALUES ('$receiver', '$sn', '$value', '$type', '$rssi', '$quality', '$battery', '$timestamp','$receiveTime')";
			
			//check the sqlStatement to see if it's correct:
			//var_dump($sqlStr); 

			//run the query
			$result = mysqli_query($con, $sqlStr);
			if(!($result)){
			echo("Error description: " . mysqli_error($con));
		}

		} 
		elseif($resultselect->num_rows > 0): //Update Existing Record in MySQL if its NOT a new Record
		{  
			//prepare the SQL Statement
			
			$sqlStr = "UPDATE ttr4postdaten SET Value = '$value', Type = '$type',  Timestamp = '$timestamp', RSSI = '$rssi',receiveTime='$receiveTime', Quality = '$quality', 
			Battery = '$battery' WHERE SN = '$sn' and Receiver = '$receiver'";
			
			//check the sqlStatement to see if it's correct:
			
		    //var_dump($sqlStr); 
			
			//run the query
			$result = mysqli_query($con, $sqlStr);
			if(!($result)){
			echo("Error description: " . mysqli_error($con));
			}

		}
	endif; 
	}
}
elseif(array_key_exists("GesysenseID",$phpArray)){
	
	    echo '{';
	   $GesysenseID= $phpArray->GesysenseID;
	   $RepitersNr= $phpArray->Repeaters;
	   $SensorsNr= $phpArray->Sensors;
	   $FWversion=$phpArray->FWversion;
	   $timestamp=$phpArray->timestamp;
	   $bootcnt=$phpArray->bootcnt;
	   $BLversion=$phpArray->BLversion;
	   $SVreceiveTime=date("Y-m-d H:i:s");
	   
	//prepare the SQL Statement
	
	$sqlStr = "INSERT INTO lifecheck (GesysenseID, FWversion, timestamp, bootcnt ,RepeatersNr ,SensorsNr,BLversion) VALUES ('$GesysenseID', '$FWversion', '$timestamp', '$bootcnt' , '$RepeatersNr','$SensorsNr','$BLversion')";
	if(!($result = mysqli_query($con, $sqlStr))){
		echo("Error description: " . mysqli_error($con));
	}
	if(floatval($BLversion) != BOOTLOADER_VERSION )
	{
		echo ' "fwupdate": {"URL": "https://rest1.gesysense.de/update/ttr4_bl_v1_04.bin"}, ';
	}
	else if(floatval($FWversion) < FW_UPDATE_VERSION )
	{
		echo ' "fwupdate": {"URL": "https://rest1.gesysense.de/update/TTR4_v0_138.bin"},  ';
		//echo ' "fwupdate": {"URL": "https://rest1.gesysense.de/update/test400.txt"}, ';
	}
	
}
else{ echo '{';}
//else{ echo 'JsonObject INVALID !';}
//check the outcome
	if ($result):
	{	
		// 	Set a response code
		//printf("<p>Update Done, SN: %s</p>", $id);
		$b = http_response_code(200);
		$c = http_response_code();
		//var_dump($c);	
		$respData = file_get_contents("respsuccess.json");
		die ($respData);
	}
	else:
	{ 
		// Set a response code
		$b = http_response_code(400);
		$c = http_response_code();
		//var_dump($c);
		//printf("<p>Update failed: %s</p>", mysqli_error($con));
		$respData = file_get_contents("resperror.json");
		die ($respData);
	}
	endif;
//sign off
//echo '<p>End of script.</p>';

 

?>